@@ -4,10 +4,12 @@ from .assets import (
     GithubReleaseAssetsPusher)
 from .manager import GithubReleaseManager
 from .release import GithubRelease
+from . import stream
 
 
 __all__ = (
     "GithubRelease",
     "GithubReleaseAssetsFetcher",
     "GithubReleaseAssetsPusher",
-    "GithubReleaseManager")
+    "GithubReleaseManager",
+    "stream")
